.. _spkg_joblib:

joblib: Lightweight pipelining with Python functions
====================================================

Description
-----------

Lightweight pipelining with Python functions

License
-------

Upstream Contact
----------------

https://pypi.org/project/joblib/



Type
----

optional


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    1.5.3

version_requirements.txt::

    joblib

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install joblib

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i joblib


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
